# pyMELA

Pure-Python Matrix Element Likelihood Analysis

[![GitHub Actions Status](https://github.com/scailfin/pyMELA/workflows/CI/CD/badge.svg)](https://github.com/scailfin/pyMELA/actions)
[![Code Coverage](https://codecov.io/gh/scailfin/pyMELA/graph/badge.svg?branch=master)](https://codecov.io/gh/scailfin/pyMELA?branch=master)
[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/scailfin/pyMELA.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/scailfin/pyMELA/latest/files/)
[![CodeFactor](https://www.codefactor.io/repository/github/scailfin/pyMELA/badge)](https://www.codefactor.io/repository/github/scailfin/pyMELA)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

[![Docs](https://img.shields.io/badge/docs-master-blue.svg)](https://scailfin.github.io/pyMELA)
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/scailfin/pyMELA/master)

[![PyPI version](https://badge.fury.io/py/pymela.svg)](https://badge.fury.io/py/pymela)
[![Supported Python versions](https://img.shields.io/pypi/pyversions/pymela.svg)](https://pypi.org/project/pymela/)

pyMELA provides matrix element analysis tools that are accelerated using machine learning.
